//+------------------------------------------------------------------+
//|                                                         TRIX.mq4 |
//|                                                                  |
//|                                        http://www.metaquotes.net |
//+------------------------------------------------------------------+

/*-------------------------------------------------------------------------
This is a triple smoothed Trix indicator.  It is revised from the original
in that a zeroline and a signal line is included.  Also, the user can
choose that the calculations be based on Close prices or Typical prices
(H+L+C/3)for a smoother line.  Length and Signal are preset to 4,4 for
ultra responsive crossings.  These settings can be changed.  Trix should
be used in conjunction with another indicator to help identify "false"
signals. 
                                                - Traderathome, 09/08/2008
--------------------------------------------------------------------------*/

#property link "http://www.metaquotes.net"
//---- indicator settings
#property indicator_separate_window
#property indicator_buffers 3 
#property indicator_color1 White     //Zero Axis Line (Always on bottom)
#property indicator_color2 Blue      //Trix Line
#property indicator_color3 Black     //Signal Line
#property  indicator_width1  1
#property  indicator_width2  2
#property  indicator_width3  2
#property  indicator_style1  STYLE_DASH
//---- input parameters
extern int Length = 4;
extern int Signal = 4;
extern int Method = 1;  //1=based on Close prices, and 2=based on Typical Prices (smoother curves).
//---- buffers
double TRIX_Buffer[];
double Signal_Buffer[];
double ZeroLine[];
double EMA1_buffer[];
double EMA2_buffer[];
double EMA3_buffer[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function |
//+------------------------------------------------------------------+
int init()
{

//---- indicators - drawing settings
SetIndexStyle(0,DRAW_LINE);
SetIndexBuffer(0,ZeroLine);
SetIndexStyle(1,DRAW_LINE);
SetIndexBuffer(1,TRIX_Buffer);
SetIndexStyle(2,DRAW_LINE);
SetIndexBuffer(2,Signal_Buffer);


//---- 3 additional buffers are used for counting.
IndicatorBuffers(6);
SetIndexBuffer(3,EMA1_buffer);
SetIndexBuffer(4,EMA2_buffer);
SetIndexBuffer(5,EMA3_buffer);

//---- name for DataWindow and indicator subwindow label
IndicatorShortName("     TRIX   ("+Length+","+Signal+")  ");
SetIndexLabel(0,"ZeroLine");
SetIndexLabel(1,"Trix");
SetIndexLabel(2,"Signal");

//----
return(0);
}
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function |
//+------------------------------------------------------------------+
int deinit()
{
return(0);
}

//+------------------------------------------------------------------+
//| Custom indicator iteration function |
//+------------------------------------------------------------------+
int start()
{
int i,limit;
int counted_bars=IndicatorCounted();

//---- check for possible errors
if(counted_bars<0) return(-1);

if(Bars<=Length) return(0);
//---- initial zero
if(counted_bars<1)
{
for(i=1;i<=Length;i++) TRIX_Buffer[Bars-i]=0.0;
for(i=1;i<=Length;i++) Signal_Buffer[Bars-i]=0.0;
for(i=1;i<=Length;i++) EMA1_buffer[Bars-i]=0.0;
for(i=1;i<=Length;i++) EMA2_buffer[Bars-i]=0.0;
for(i=1;i<=Length;i++) EMA3_buffer[Bars-i]=0.0;
}
int method;
if (Method<=1) Method = PRICE_CLOSE;
if (Method>1) Method = PRICE_TYPICAL;
if(counted_bars>0) counted_bars--;
limit=Bars-counted_bars;

for(i=0; i<limit-1; i++)
ZeroLine[i] = 0;
for(i=0; i<limit; i++)
EMA1_buffer[i]=iMA(NULL,0,Length,0,MODE_EMA,Method,i); //PRICE_TYPICAL=smoother curve than PRICE_CLOSE
for(i=0; i<limit; i++)
EMA2_buffer[i]=iMAOnArray(EMA1_buffer,Bars,Length,0,MODE_EMA,i);
for(i=0; i<limit; i++)
EMA3_buffer[i]=iMAOnArray(EMA2_buffer,Bars,Length,0,MODE_EMA,i);
for(i=0; i<limit-1; i++)
TRIX_Buffer[i] = (EMA3_buffer[i] - EMA3_buffer[i+1]) / EMA3_buffer[i+1] *100;
for(i=0; i<limit-1; i++)
Signal_Buffer[i]=iMAOnArray(TRIX_Buffer,Bars,Signal,0,MODE_SMA,i);


return(0);
}

//+------------------------------------------------------------------+